# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-01-15 23:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Record',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('create_time', models.DateTimeField()),
                ('message', models.TextField()),
                ('level', models.SmallIntegerField()),
                ('level_name', models.CharField(max_length=16)),
                ('function', models.CharField(max_length=80)),
                ('module', models.CharField(max_length=80)),
                ('path', models.CharField(max_length=260)),
                ('filename', models.CharField(max_length=80)),
                ('line', models.IntegerField()),
                ('logger', models.CharField(max_length=80)),
                ('process', models.IntegerField()),
                ('process_name', models.CharField(max_length=80)),
                ('thread', models.IntegerField()),
                ('thread_name', models.CharField(max_length=80)),
            ],
        ),
    ]



from django.contrib import admin

from dblog.models import Record

class RecordAdmin(admin.ModelAdmin):
    list_display = [
        'create_time',
        'logger',
        'level_name',
        'list_message',
    ]
    readonly_fields = [field.name for field in Record._meta.fields]

    def list_message(self, record):
        lines = record.message.splitlines()
        return lines[0]

    list_message.short_description = 'Message'

admin.site.register(Record, RecordAdmin)



"""Django Database Log

"""

from .handlers import DBLogHandler


__title__ = 'dblog'
__version__ = '0.2.0'
__build__ = 0x000200
__author__ = 'Grant Jenks'
__license__ = 'Apache 2.0'
__copyright__ = '2018-2019, Grant Jenks'



"""Django Database Logs Models

"""

from django.db import models


class Record(models.Model):
    create_time = models.DateTimeField()
    message = models.TextField()
    level = models.BigIntegerField()
    level_name = models.CharField(max_length=16)
    function = models.CharField(max_length=80)
    module = models.CharField(max_length=80)
    path = models.CharField(max_length=260)
    filename = models.CharField(max_length=80)
    line = models.BigIntegerField()
    logger = models.CharField(max_length=80)
    process = models.BigIntegerField()
    process_name = models.CharField(max_length=80)
    thread = models.BigIntegerField()
    thread_name = models.CharField(max_length=80)

    def __str__(self):
        return self.message



import logging

from django.utils import timezone

import pytest

from .models import Record

@pytest.mark.django_db
def test_record():
    record = Record.objects.create(
        create_time=timezone.now(),
        message='This is a test.',
        level=logging.INFO,
        level_name='INFO',
        function='test_record',
        module='tests',
        path='dblog/tests.py',
        line=0,
        logger='test',
        process=123,
        process_name='Test Process',
        thread=456,
        thread_name='Test Thread',
    )
    assert str(record) == 'This is a test.'



import logging

from django.utils import timezone


class DBLogHandler(logging.Handler):
    def emit(self, record):
        # Logging is initialized before Django apps are registered so model
        # imports must be delayed.
        from .models import Record

        kwargs = {
            'create_time': timezone.now(),
            'message': self.format(record),
            'level': record.levelno,
            'level_name': record.levelname,
            'function': record.funcName,
            'module': record.module,
            'path': record.pathname,
            'filename': record.filename,
            'line': record.lineno,
            'logger': record.name,
            'process': record.process,
            'process_name': record.processName,
            'thread': record.thread,
            'thread_name': record.threadName,
        }

        Record.objects.create(**kwargs)



from setuptools import setup, find_packages
from setuptools.command.test import test as TestCommand

import dblog


class Tox(TestCommand):
    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True
    def run_tests(self):
        import tox
        errno = tox.cmdline(self.test_args)
        exit(errno)


with open('README.rst') as reader:
    readme = reader.read()

setup(
    name='django-dblog',
    version=dblog.__version__,
    description='Django Database Logs',
    long_description=readme,
    author='Grant Jenks',
    author_email='contact@grantjenks.com',
    url='http://www.grantjenks.com/docs/django-dblog/',
    license='Apache 2.0',
    packages=find_packages(exclude=('docs', 'tests')),
    tests_require=['tox'],
    cmdclass={'test': Tox},
    classifiers=(
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: Implementation :: CPython',
    ),
)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.18 on 2019-01-16 00:26
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('dblog', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='record',
            name='level',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='record',
            name='line',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='record',
            name='process',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='record',
            name='thread',
            field=models.BigIntegerField(),
        ),
    ]
